@@ -1,13 +1,19 @@
 from __future__ import annotations
 
+import sys
 import asyncio
 import collections
 import time
 import traceback
-from typing import Any, Dict, List, Optional, Set, Tuple
+from typing import Optional
 from dataclasses import dataclass
 import urllib.parse
 
+import ModuleUpdate
+import Utils
+from NetUtils import ClientStatus
+from CommonClient import gui_enabled, logger, get_base_parser, ClientCommandProcessor, \
+    server_loop
 from .options import SmsOptions
 from .bit_helper import change_endian, bit_flagger, extract_bits
 import dolphin_memory_engine as dme
@@ -21,11 +27,6 @@ apname = Utils.instance_name if Utils.instance_name else "Archipelago"
 
 '''
 
-
-from NetUtils import ClientStatus
-from CommonClient import gui_enabled, logger, get_base_parser, ClientCommandProcessor, \
-    CommonContext, server_loop
-
 CONNECTION_REFUSED_GAME_STATUS = (
     "Dolphin failed to connect. Please load a randomized ROM for Super Mario Sunshine. Trying again in 5 seconds..."
 )
@@ -40,10 +41,11 @@ CONNECTION_INITIAL_STATUS = "Dolphin connection has not been initiated."
 
 ticket_listing = []
 world_flags = {}
-debug = False
-debug_b = False
 
-game_ver = 0x3a
+DEBUG = False
+GAME_VER = 0x3a
+AP_WORLD_VERSION_NAME = "0.6.4"
+CLIENT_VERSION = "0.5.0"
 
 
 @dataclass
@@ -72,10 +74,10 @@ class SmsCommandProcessor(ClientCommandProcessor):
         self.ctx.syncing = True
         refresh_collection_counts(self.ctx)
 
-
-class SmsContext(CommonContext):
-    command_processor: SmsCommandProcessor
+class SmsContext(SuperContext):
+    command_processor = SmsCommandProcessor
     game = "Super Mario Sunshine"
+    tags = {"AP"}
     items_handling = 0b111  # full remote
 
     options: SmsOptions
@@ -90,15 +92,14 @@ class SmsContext(CommonContext):
 
     plaza_episode = 0
 
-    yoshi_check = False
-
     goal = 50
     corona_message_given = False
     blue_status = 1
     fludd_start = 0
-    yoshi_mode = 0
+    bianco_flag = 0
     ticket_mode = False
     victory = False
+    checked_yoshi_egg = False
 
     ap_nozzles_received = []
 
@@ -112,6 +113,7 @@ class SmsContext(CommonContext):
         self.dolphin_sync_task: Optional[asyncio.Task[None]] = None
         self.dolphin_status: str = CONNECTION_INITIAL_STATUS
         self.awaiting_rom: bool = False
+        self.has_send_death: bool = False
         self.username = urllib.parse.urlparse(server_address).username
         if self.ready_callback:
             from kivy.clock import Clock
@@ -144,6 +146,8 @@ class SmsContext(CommonContext):
     #     self.ui_task = asyncio.create_task(self.ui.async_run(), name="UI")
 
     def on_package(self, cmd: str, args: dict):
+        super().on_package(cmd, args)
+
         if cmd == "Connected":
             slot_data = args.get("slot_data")
             self.goal = slot_data.get("corona_mountain_shines")
@@ -153,13 +157,22 @@ class SmsContext(CommonContext):
             temp = slot_data.get("starting_nozzle")
             if temp:
                 self.fludd_start = temp
-            temp = slot_data.get("yoshi_mode")
-            if temp:
-                self.yoshi_mode = temp
             temp = slot_data.get("ticket_mode")
             if temp:
                 self.ticket_mode = temp
 
+            if "death_link" in slot_data:
+                Utils.async_start(self.update_death_link(bool(slot_data["death_link"])))
+
+    def on_deathlink(self, data: dict):
+        super().on_deathlink(data)
+        source = data.get('source', 'Unknown')
+        cause = data.get('cause', 'No cause specified')
+        logger.info(f"DeathLink received! Source: {source}")
+        logger.info(f"DeathLink message: {cause}")
+        logger.info("Killing Mario now...")
+        kill_mario(self)
+
     def get_corona_goal(self):
         if self.goal:
             return self.goal
@@ -169,42 +182,71 @@ class SmsContext(CommonContext):
 
 storedShines = []
 curShines = []
-delaySeconds = .5
-location_offset = 523000
+storedBlues = []
+curBlues = []
+storedNozzleBoxes = []
+curNozzleBoxes = []
+
+DELAY_SECONDS = .5
+LOCATION_OFFSET = 523000
 
 def read_string(console_address: int, strlen: int) -> str:
     return dme.read_bytes(console_address, strlen).split(b"\0", 1)[0].decode()
 
 
 def game_start():
-    for x in range(0, addresses.SMS_SHINE_BYTE_COUNT):
+    for _ in range(0, addresses.SMS_SHINE_BYTE_COUNT):
         storedShines.append(0x00)
         curShines.append(0x00)
-    # dme.hook()
-    # return dme.is_hooked()
+    for _ in range(0, addresses.SMS_BLUECOIN_BYTE_COUNT):
+        storedBlues.append(0x00)
+        curBlues.append(0x00)
+    for _ in range(0, addresses.NOZZLE_BOXES_BYTE_COUNT):
+        storedNozzleBoxes.append(0x00)
+        curNozzleBoxes.append(0x00)
+
+# Apparently when you beat the game it considers current stage AS FILE SELECT
+# Therefore it wasn't sending out the Victory check
+def in_file_select():
+    return dme.read_byte(addresses.SMS_CURRENT_STAGE) == 15
 
 
 async def game_watcher(ctx: SmsContext):
+    previous_lives = None
+
     while not ctx.exit_event.is_set():
+        '''
+        dme.is_hooked() returns true if just the emulation stops, as dolphin itself is still running
+        this causes the dme to write into a non existing memory, resulting in the crashes.
+        changed if to check based on connection status, and unhooking DME properly if connection is lost (Exception)
+
+        ctx.slot None means we are not connected to the AP server.
+        '''
+        if not dme.is_hooked() or ctx.slot is None:
+            await asyncio.sleep(5)
+            continue
+
+        # if in_file_select():
+        #     await asyncio.sleep(1)
+        #     continue
+
+        await handle_stages(ctx)
+        await location_watcher(ctx)
+
+        if "DeathLink" in ctx.tags:
+            await check_death(ctx, previous_lives)
+            try:
+                previous_lives = dme.read_byte(addresses.SMS_LIVES_COUNTER)
+            except:
+                pass
 
         sync_msg = [{'cmd': 'Sync'}]
         if ctx.locations_checked:
             sync_msg.append({"cmd": "LocationChecks", "locations": list(ctx.locations_checked)})
         await ctx.send_msgs(sync_msg)
 
-        #Gravi01 Begin      
-        '''
-        dme.is_hooked() returns true if just the emulation stops, as dolphin itself is still running
-        this causes the dme to write into a non existing memory, resulting in the crashes.
-        changed if to check based on connection status, and unhooking DME properly if connection is lost (Exception)
-        ''' 
-        if ctx.dolphin_status == CONNECTION_CONNECTED_STATUS:
-            try:
-                refresh_collection_counts(ctx)
-            except Exception:
-                logger.info("Connection to Dolphin lost, reconnecting...")
-                ctx.dolphin_status = CONNECTION_LOST_STATUS
-                dme.un_hook()
+        #Gravi01 Begin
+        refresh_collection_counts(ctx)
         ctx.lives_switch = True
         #Gravi01 End
 
@@ -216,30 +258,79 @@ async def game_watcher(ctx: SmsContext):
         ctx.lives_switch = False
 
 
-async def location_watcher(ctx):
-    def _sub():
-        if not dme.is_hooked():
-            return
-
-        for x in range(0, addresses.SMS_SHINE_BYTE_COUNT):
-            targ_location = addresses.SMS_SHINE_LOCATION_OFFSET + x
-            cache_byte = dme.read_byte(targ_location)
-            curShines[x] = cache_byte
-
-        if storedShines != curShines:
-            memory_changed(ctx)
-
+async def check_death(ctx: SmsContext, previous_lives):
+    """Check if Mario died by comparing current lives with previous lives, then send DeathLink."""
+    if ctx.slot is None or previous_lives is None:
         return
 
-    while not ctx.exit_event.is_set():
-        #Gravi01 Begin      #Changing dme.is_Hooked => Connection Status 
-        #if not dme.is_hooked():
-            #dme.hook()
-        #else:
-        if ctx.dolphin_status == CONNECTION_CONNECTED_STATUS:
-        #Gravi01 End
-            _sub()
-        await asyncio.sleep(delaySeconds)
+    try:
+        current_lives = dme.read_byte(addresses.SMS_LIVES_COUNTER)
+        if current_lives < previous_lives:
+            if not ctx.has_send_death and time.time() >= ctx.last_death_link + 3:
+                ctx.has_send_death = True
+                player_name = ctx.player_names[ctx.slot] if ctx.slot in ctx.player_names else "Player"
+                await ctx.send_death(f"{player_name} died!")
+                logger.info(f"Sent DeathLink: Mario died (lives {previous_lives} -> {current_lives})")
+        else:
+            ctx.has_send_death = False
+    except Exception as e:
+        logger.error(f"Error checking death: {e}")
+
+
+async def location_watcher(ctx):
+    for x in range(0, addresses.SMS_SHINE_BYTE_COUNT):
+        targ_location = addresses.SMS_SHINE_LOCATION_OFFSET + x
+        cache_byte = dme.read_byte(targ_location)
+        curShines[x] = cache_byte
+        if storedShines[x] != curShines[x]:
+            memory_changed(ctx, x, curShines[x])
+            storedShines[x] = curShines[x]
+
+    # If possible, check if blue coin sanity is enabled or not
+    for x in range(0, addresses.SMS_BLUECOIN_BYTE_COUNT):
+        targ_location = addresses.SMS_BLUECOIN_LOCATION_OFFSET + x
+        cache_byte = dme.read_byte(targ_location)
+        curBlues[x] = cache_byte
+        if storedBlues[x] != curBlues[x]:
+            memory_changed(ctx, x+15, curBlues[x]) # Add 15 to 'x' to align with blue coin IDs
+            storedBlues[x] = curBlues[x]
+
+    for x in range(0, addresses.NOZZLE_BOXES_BYTE_COUNT):
+        targ_location = addresses.NOZZLE_BOXES_FLAGS_OFFSET + x
+        cache_byte = dme.read_byte(targ_location)
+        curNozzleBoxes[x] = cache_byte
+        if storedNozzleBoxes[x] != curNozzleBoxes[x]:
+            memory_changed(ctx, x+108, curNozzleBoxes[x])
+            storedNozzleBoxes[x] = curNozzleBoxes[x]
+
+    # Check corresponds to Shadow Mario Yoshi Egg Chase
+    delfino_yoshi_unlock = dme.read_byte(addresses.DELFINO_YOSHI_UNLOCK)
+    if (delfino_yoshi_unlock & 0x80) and not ctx.checked_yoshi_egg:
+        ctx.checked_yoshi_egg = True
+        memory_changed(ctx, 113, delfino_yoshi_unlock)
+    return
+
+
+async def handle_stages(ctx):
+    #Gravi01  change to connection status
+    next_stage = dme.read_byte(addresses.SMS_NEXT_STAGE)
+    cur_stage = dme.read_byte(addresses.SMS_CURRENT_STAGE)
+    if next_stage == 0x01: # Delfino Plaza
+        next_episode = dme.read_byte(addresses.SMS_NEXT_EPISODE)
+
+        # If starting Fluddless without ticket mode on, open Bianco Hills
+        if not ctx.bianco_flag and ctx.fludd_start == 2 and ctx.ticket_mode == 0:
+            ctx.bianco_flag |= dme.read_byte(TICKETS[0].address)
+            dme.write_byte(TICKETS[0].address, ctx.bianco_flag)
+            open_stage(TICKETS[0])
+        # Sets plaza state to 8 if it is not and goal hasn't been reached
+        if ctx.ticket_mode == 1 and next_episode != 0x8 and not ctx.corona_message_given:
+            dme.write_byte(addresses.SMS_NEXT_EPISODE, 8)
+    if cur_stage != next_stage:
+        await send_map_id(next_stage, ctx)
+        if ctx.ticket_mode:
+            await resolve_tickets(next_stage, ctx)
+
 
 async def dolphin_sync_task(ctx: SmsContext) -> None:
     logger.info("Starting Dolphin connector. Use /dolphin for status information.")
@@ -255,14 +346,14 @@ async def dolphin_sync_task(ctx: SmsContext) -> None:
                 if ctx.awaiting_rom:
                     await ctx.server_auth()
                 await asyncio.sleep(0.1)
-            else:   
+            else:
                 if ctx.dolphin_status == CONNECTION_CONNECTED_STATUS:
                     logger.info("Connection to Dolphin lost, reconnecting...")
                     ctx.dolphin_status = CONNECTION_LOST_STATUS
                 logger.info("Attempting to connect to Dolphin...")
                 dme.hook()
                 if dme.is_hooked():
-                    if dme.read_bytes(0x80000000, 6) != b"GMSE01":
+                    if dme.read_bytes(0x80000000, 6) != b"GMSEAP":
                         logger.info(CONNECTION_REFUSED_GAME_STATUS)
                         ctx.dolphin_status = CONNECTION_REFUSED_GAME_STATUS
                         dme.un_hook()
@@ -271,6 +362,7 @@ async def dolphin_sync_task(ctx: SmsContext) -> None:
                         logger.info(CONNECTION_CONNECTED_STATUS)
                         ctx.dolphin_status = CONNECTION_CONNECTED_STATUS
                         ctx.locations_checked = set()
+                        await asyncio.sleep(5)
                 else:
                     logger.info("Connection to Dolphin failed, attempting again in 5 seconds...")
                     dme_status = dme.get_status()
@@ -286,28 +378,32 @@ async def dolphin_sync_task(ctx: SmsContext) -> None:
             await ctx.disconnect()
             await asyncio.sleep(5)
             continue
-        
+
 
 async def arbitrary_ram_checks(ctx):
-    activated_bits = dme.read_byte(addresses.ARB_NOZZLES_ENABLER)
+    while not ctx.exit_event.is_set():
+        if not dme.is_hooked() or ctx.slot is None:
+            await asyncio.sleep(5)
+            continue
+
+        activated_bits = dme.read_byte(addresses.ARB_NOZZLES_ENABLER)
 
-    while dme.is_hooked():
         for noz in ctx.ap_nozzles_received:
             if noz < 4:
                 activated_bits = bit_flagger(activated_bits, noz, True)
                 dme.write_byte(addresses.ARB_FLUDD_ENABLER, 0x1)
                 dme.write_byte(addresses.ARB_NOZZLES_ENABLER, activated_bits)
-        await asyncio.sleep(delaySeconds)
+        await asyncio.sleep(DELAY_SECONDS)
 
 
-def memory_changed(ctx: SmsContext):
-    if debug: logger.info("memory_changed: " + str(curShines))
+def memory_changed(ctx: SmsContext, bit_pos, cached_byte):
+    if DEBUG: logger.info(f"memory_changed: {cached_byte}, bit_pos: {bit_pos}")
     bit_list = []
-    for x in range(0, addresses.SMS_SHINE_BYTE_COUNT):
-        bit_found = extract_bits((curShines[x]), x)
-        bit_list.extend(bit_found)
-        storedShines[x] = curShines[x]
-    if debug: logger.info("bit_list: " + str(bit_list))
+
+    bit_found = extract_bits(cached_byte, bit_pos)
+    bit_list.extend(bit_found)
+
+    # if DEBUG: logger.info("bit_list: " + str(bit_list))
     parse_bits(bit_list, ctx)
 
 
@@ -319,7 +415,7 @@ def send_victory(ctx: SmsContext):
     ctx.send_msgs([{"cmd": "StatusUpdate", "status": ClientStatus.CLIENT_GOAL}])
     logger.info("Congratulations on completing your seed!")
     time.sleep(.05)
-    logger.info("MultiworldGG SUPER MARIO SUNSHINE CREDITS:")
+    logger.info("ARCHIPELAGO SUPER MARIO SUNSHINE CREDITS:")
     time.sleep(.05)
     logger.info("MrsMarinaRose - Client, Modding and Patching")
     time.sleep(.05)
@@ -333,6 +429,8 @@ def send_victory(ctx: SmsContext):
     time.sleep(.05)
     logger.info("Quizzeh - Extra testing")
     time.sleep(.05)
+    # logger.info("DoubleDubbel - The Incredible Name For The Randomizer ISO")
+    # time.sleep(.05)
     logger.info("Spicynun - Additional research")
     time.sleep(.05)
     logger.info("JoshuaMKW - Sunshine Toolset")
@@ -346,19 +444,16 @@ def send_victory(ctx: SmsContext):
 
 
 def parse_bits(all_bits, ctx: SmsContext):
-    if debug: logger.info("parse_bits: " + str(all_bits))
+    if DEBUG: logger.info("parse_bits: " + str(all_bits))
     if len(all_bits) == 0:
         return
 
     for x in all_bits:
-        if x < 119:
-            temp = x + location_offset
+        if x != 119 and x <= 911:
+            temp = x + LOCATION_OFFSET
             ctx.locations_checked.add(temp)
-            if debug: logger.info("checks to send: " + str(temp))
-        elif 119 < x <= 549:
-            temp = x + location_offset
-            ctx.locations_checked.add(temp)
-        if x == 119:
+            if DEBUG: logger.info("checks to send: " + str(temp))
+        elif x == 119:
             send_victory(ctx)
 
 
@@ -384,9 +479,9 @@ def refresh_item_count(ctx, item_id, targ_address):
 
 def refresh_all_items(ctx: SmsContext):
     counts = collections.Counter(received_item.item for received_item in ctx.items_received)
-    for items in counts:
-        if counts[items] > 0:
-            unpack_item(items, ctx, counts[items])
+    for item in counts:
+        if counts[item] > 0:
+            unpack_item(item, ctx)
     if counts[523004] >= ctx.get_corona_goal():
         activate_ticket(999999)
         if not ctx.corona_message_given:
@@ -395,7 +490,7 @@ def refresh_all_items(ctx: SmsContext):
 
 
 def refresh_collection_counts(ctx):
-    #if debug: logger.info("refresh_collection_counts")
+    #if DEBUG: logger.info("refresh_collection_counts")
     refresh_item_count(ctx, 523004, addresses.SMS_SHINE_COUNTER)
     if ctx.blue_status == 1:
         refresh_item_count(ctx, 523014, addresses.SMS_BLUECOIN_COUNTER)
@@ -414,6 +509,7 @@ def check_world_flags(byte_location, byte_pos, bool_setting):
 
 def open_stage(ticket):
     value = check_world_flags(ticket.address, ticket.bit_position, True)
+    value |= dme.read_byte(ticket.address)
     dme.write_byte(ticket.address, value)
     return
 
@@ -423,7 +519,7 @@ def special_noki_handling():
     return
 
 
-def unpack_item(item, ctx, amt=0):
+def unpack_item(item, ctx):
     if 522999 < item < 523004:
         activate_nozzle(item, ctx)
     elif item == 523013:
@@ -432,9 +528,9 @@ def unpack_item(item, ctx, amt=0):
         activate_ticket(item)
 
 
-def disable_shadow_mario():
-    if dme.is_hooked():
-        dme.write_double(addresses.SMS_SHADOW_MARIO_STATE, 0)
+# def disable_shadow_mario():
+#     if dme.is_hooked():
+#         dme.write_double(addresses.SMS_SHADOW_MARIO_STATE, 0)
 
 
 @dataclass
@@ -477,38 +573,24 @@ def handle_ticket(tick: Ticket):
     open_stage(tick)
     return
 
-
+# Not even used
 def refresh_all_tickets():
     for tickets in TICKETS:
         handle_ticket(tickets)
 
 
-def extra_unlocks_needed():
-    if not dme.is_hooked():
-        return
-    dme.write_byte(addresses.SMS_YOSHI_UNLOCK-1, 240)
-    val = bit_flagger((dme.read_byte(addresses.SMS_YOSHI_UNLOCK)), 1, True)
-    dme.write_byte(addresses.SMS_YOSHI_UNLOCK, val)
-
-
 def activate_nozzle(id, ctx):
     if id == 523000:
         if not ctx.ap_nozzles_received.__contains__(0):
             ctx.ap_nozzles_received.append(0)
-    if id == 523001:
+    elif id == 523001:
         if not ctx.ap_nozzles_received.__contains__(1):
             ctx.ap_nozzles_received.append(1)
-
-    if id == 523013:
-        temp = dme.read_byte(addresses.SMS_YOSHI_UNLOCK)
-        if temp < 2:
-            dme.write_byte(addresses.SMS_YOSHI_UNLOCK, 2)
-        extra_unlocks_needed()
-    if id == 523002:
+    elif id == 523002:
         if not ctx.ap_nozzles_received.__contains__(2):
             ctx.ap_nozzles_received.append(2)
         # rocket nozzle
-    if id == 523003:
+    elif id == 523003:
         if not ctx.ap_nozzles_received.__contains__(3):
             ctx.ap_nozzles_received.append(3)
         # turbo nozzle
@@ -516,33 +598,36 @@ def activate_nozzle(id, ctx):
 
 
 def activate_yoshi(ctx):
-    temp = dme.read_byte(addresses.SMS_YOSHI_UNLOCK)
-    if temp < 130:
-        dme.write_byte(addresses.SMS_YOSHI_UNLOCK, 0x80)
-        # BEGIN YOSHI BANDAID
-    if ctx.yoshi_mode:
-        flag = dme.read_byte(0x8057898c)
-        new_flag = bit_flagger(flag, 1, True)
-        dme.write_byte(0x8057898c, new_flag)
-    # END YOSHI BANDAID
-    extra_unlocks_needed()
-
+    dme.write_byte(0x80417A03, 0x01)
     if not ctx.ap_nozzles_received.__contains__(4):
         ctx.ap_nozzles_received.append(4)
     return
 
 
-def resolve_tickets(stage, ctx):
+def kill_mario(ctx: SmsContext):
+    """Uses the same logic as Gecko code death trigger"""
+    if ctx.slot is not None and dme.is_hooked() and ctx.dolphin_status == CONNECTION_CONNECTED_STATUS:
+        try:
+            pointer_addr = 0x8040E178
+            pointer_value = int.from_bytes(dme.read_bytes(pointer_addr, 4), byteorder="big")
+            actual_target = pointer_value + 0x4C
+
+            dme.write_bytes(actual_target, (0x4020).to_bytes(2, byteorder="big"))
+            ctx.has_send_death = True
+        except Exception as e:
+            logger.error(f"Failed to kill Mario - connection may be lost: {e}")
+    return
+
+
+async def resolve_tickets(stage, ctx):
     for tick in TICKETS:
         if tick.course_id == stage and not tick.active:
             logger.info("Entering a stage without a ticket! Initiating bootout...")
             # Byte 1 should correspond to Delfino Plaza
             dme.write_byte(addresses.SMS_NEXT_STAGE, 1)
-            #dme.write_byte(addresses.SMS_NEXT_EPISODE, 8)
             dme.write_byte(addresses.SMS_CURRENT_STAGE, 1)
-            #dme.write_byte(addresses.SMS_CURRENT_STAGE, ctx.plaza_episode)
         else:
-            send_map_id(stage, ctx)
+            await send_map_id(stage, ctx)
     return
 
 # Checks to see if player changed stages to update map_id for Poptracker
@@ -611,23 +696,20 @@ def launch(server_address: str = None, password: str = None, ready_callback=None
 
         ctx.ui.base_title = apname + " | Super Mario Sunshine"
         ctx.server_task = asyncio.create_task(server_loop(ctx), name="ServerLoop")
+
+        # ctx._main()
+
+        if TRACKER_LOADED:
+            ctx.run_generator()
         await ctx.server_auth()
 
         await asyncio.sleep(1)
         game_start()
 
-        ctx.dolphin_sync_task = asyncio.create_task(dolphin_sync_task(ctx), name="DolphinSync")
+        ctx.dolphin_sync_task = asyncio.create_task(dolphin_sync_task(ctx), name="SmsDolphinSync")
 
         progression_watcher = asyncio.create_task(game_watcher(ctx), name="SmsProgressionWatcher")
-        loc_watch = asyncio.create_task(location_watcher(ctx))
-        stage_watch = asyncio.create_task(handle_stages(ctx))
-        arbitrary = asyncio.create_task(arbitrary_ram_checks(ctx))
-
-        await progression_watcher
-        await loc_watch
-        await stage_watch
-        await arbitrary
-        await asyncio.sleep(.25)
+        arbitrary = asyncio.create_task(arbitrary_ram_checks(ctx), name="SmsArbitraryWatcher")
 
         await ctx.exit_event.wait()
         ctx.server_address = None
@@ -635,10 +717,12 @@ def launch(server_address: str = None, password: str = None, ready_callback=None
         await ctx.shutdown()
 
         if ctx.dolphin_sync_task:
-            await asyncio.sleep(3)
             await ctx.dolphin_sync_task
 
-    import colorama
+        if progression_watcher:
+            await progression_watcher
+        if arbitrary:
+            await arbitrary
 
     # Check if we're already in an event loop (GUI mode) first
     try:
@@ -660,6 +744,5 @@ def main(server_address: str = None, password: str = None, ready_callback=None,
 
 
 if __name__ == "__main__":
-    parser = get_base_parser(description="Super Mario Sunshine Client, for text interfacing.")
-    args, rest = parser.parse_known_args()
-    main(args.connect, args.password)
+    Utils.init_logging("SMSClient", exception_logger="Client")
+    main(*sys.argv[1:])
