@@ -1,14 +1,17 @@
 SMS_SHINE_COUNTER = 0x80578A5b
 SMS_BLUECOIN_COUNTER = 0x80578a5f
+SMS_LIVES_COUNTER = 0x80578A07
 
 SMS_SHINE_LOCATION_OFFSET = 0x80578988
-SMS_SHINE_BYTE_COUNT = 69
+SMS_SHINE_BYTE_COUNT = 15
 SMS_BLUECOIN_LOCATION_OFFSET = 0x80578997
-SMS_BLUECOIN_BYTE_COUNT = 30
+SMS_BLUECOIN_BYTE_COUNT = 55 # Should be 30 bytes, but the RAM takes up space for useless Blue Coins in memory
+
+NOZZLE_BOXES_FLAGS_OFFSET = 0x805789F4
+NOZZLE_BOXES_BYTE_COUNT = 3
+DELFINO_YOSHI_UNLOCK = 0x805789F9
 
 SMS_UNKNOWN_THING = 0x81006D57
-SMS_PRIMARY_NOZZLE_ADDRESS = 0x8026A044
-SMS_SECONDARY_NOZZLE_ADDRESS = 0x80269F50
 
 SMS_SPRAY_NOZZLE_VALUE = "3BE00000"
 SMS_HOVER_NOZZLE_VALUE = "3BE00004"
@@ -27,8 +30,6 @@ NEW_ROCKET_VALUE = "41555500"
 NEW_TURBO_VALUE = "80AAAA00"
 NEW_TOTAL_VALUE = "c3ffff00"
 
-SMS_YOSHI_UNLOCK = 0x805789f9
-
 SMS_SPECIAL_FLAG = 0x80600040
 
 SMS_NOKI_REQ = 0x802b79e3
@@ -41,12 +42,7 @@ SMS_CURRENT_EPISODE = 0x803e970f
 SMS_NEXT_STAGE = 0x803e9712
 SMS_NEXT_EPISODE = 0x803e9713
 
-SMS_SHADOW_MARIO_STATE = 0x80578A88
-
-SMS_LIVES_COUNTER = 0x80578a04
-
-SMS_BOX_DISABLE = 0x8026a164
-
-ARB_NOZZLES_ENABLER = 0x80417801
-ARB_FLUDD_ENABLER = 0x80417800
-ARB_VERSION_CHECKER = 0x80578AA4
\ No newline at end of file
+# Move elsewhere maybe
+ARB_NOZZLES_ENABLER = 0x80417A01
+ARB_FLUDD_ENABLER = 0x80417A00
+ARB_VERSION_CHECKER = 0x80578AA4
